@@ -12,17 +12,7 @@ __all__ = [
 # IMPORTS #
 ###########
 
-# Full
-
-import matplotlib.colors as mplc
-import matplotlib.image as mpli
-import matplotlib.pyplot as pp
-import matplotlib.ticker as mplt
-import networkx as nx
-import numpy as np
-import numpy.linalg as npl
-
-# Partial
+# Standard
 
 from inspect import (
     trace
@@ -32,16 +22,49 @@ from io import (
     BytesIO
 )
 
+# noinspection PyPep8Naming
 from subprocess import (
     call,
-    PIPE
+    PIPE as pipe
 )
 
+# Libraries
+
+import matplotlib.colors as mplc
+import matplotlib.image as mpli
+import matplotlib.pyplot as mplp
+import matplotlib.ticker as mplt
+import networkx as nx
+import numpy as np
+import numpy.linalg as npl
+
 # Internal
 
-from .custom_types import *
-from .utilities import *
-from .validation import *
+from .custom_types import (
+    oplot,
+    ostate,
+    ostatus,
+    tdists_flex,
+    tlist_str,
+    tmc,
+    twalk_flex
+)
+
+from .utilities import (
+    generate_validation_error
+)
+
+from .validation import (
+    validate_boolean,
+    validate_distribution,
+    validate_dpi,
+    validate_enumerator,
+    validate_integer,
+    validate_markov_chain,
+    validate_state,
+    validate_states,
+    validate_status
+)
 
 
 #############
@@ -63,9 +86,12 @@ def plot_eigenvalues(mc: tmc, dpi: int = 100) -> oplot:
     """
     The function plots the eigenvalues of the Markov chain on the complex plane.
 
+    | **Notes:**
+
+    * If `Matplotlib <https://matplotlib.org/>`_ is in `interactive mode <https://matplotlib.org/stable/users/interactive.html>`_, the plot is immediately displayed and the function does not return the plot handles.
+
     :param mc: the target Markov chain.
-    :param dpi: the resolution of the plot expressed in dots per inch (by default, 100).
-    :return: None if Matplotlib is in interactive mode as the plot is immediately displayed, otherwise the handles of the plot.
+    :param dpi: the resolution of the plot expressed in dots per inch.
     :raises ValidationError: if any input argument is not compliant.
     """
 
@@ -77,10 +103,10 @@ def plot_eigenvalues(mc: tmc, dpi: int = 100) -> oplot:
     except Exception as e:  # pragma: no cover
         raise generate_validation_error(e, trace()) from None
 
-    figure, ax = pp.subplots(dpi=dpi)
+    figure, ax = mplp.subplots(dpi=dpi)
 
-    handles = list()
-    labels = list()
+    handles = []
+    labels = []
 
     theta = np.linspace(0.0, 2.0 * np.pi, 200)
 
@@ -109,7 +135,7 @@ def plot_eigenvalues(mc: tmc, dpi: int = 100) -> oplot:
                 z_spectral_gap = x_spectral_gap**2.0 + y_spectral_gap**2.0
 
                 h = ax.contourf(x_spectral_gap, y_spectral_gap, z_spectral_gap, alpha=0.2, colors='r', levels=[mu**2.0, 1.0])
-                handles.append(pp.Rectangle((0.0, 0.0), 1.0, 1.0, fc=h.collections[0].get_facecolor()[0]))
+                handles.append(mplp.Rectangle((0.0, 0.0), 1.0, 1.0, fc=h.collections[0].get_facecolor()[0]))
                 labels.append('Spectral Gap')
 
                 ax.plot(x_slem_circle, y_slem_circle, color='red', linestyle='--', linewidth=1.5)
@@ -134,10 +160,10 @@ def plot_eigenvalues(mc: tmc, dpi: int = 100) -> oplot:
     ax.legend(handles[::-1], labels[::-1], bbox_to_anchor=(0.5, -0.1), loc='upper center', ncol=len(handles))
     ax.set_title('Eigenplot', fontsize=15.0, fontweight='bold')
 
-    pp.subplots_adjust(bottom=0.2)
+    mplp.subplots_adjust(bottom=0.2)
 
-    if pp.isinteractive():  # pragma: no cover
-        pp.show(block=False)
+    if mplp.isinteractive():  # pragma: no cover
+        mplp.show(block=False)
         return None
 
     return figure, ax
@@ -148,16 +174,18 @@ def plot_graph(mc: tmc, nodes_color: bool = True, nodes_type: bool = True, edges
     """
     The function plots the directed graph of the Markov chain.
 
-    | **Notes:** Graphviz and Pydot are not required, but they provide access to extended graphs with additional features.
+    | **Notes:**
+
+    * If `Matplotlib <https://matplotlib.org/>`_ is in `interactive mode <https://matplotlib.org/stable/users/interactive.html>`_, the plot is immediately displayed and the function does not return the plot handles.
+    * `Graphviz <https://graphviz.org/>`_ and `pydot <https://pypi.org/project/pydot/>`_ are not required, but they provide access to extended graphs with additional features.
 
     :param mc: the target Markov chain.
-    :param nodes_color: a boolean indicating whether to display colored nodes based on communicating classes (by default, True).
-    :param nodes_type: a boolean indicating whether to use a different shape for every node type (by default, True).
-    :param edges_color: a boolean indicating whether to display edges using a gradient based on transition probabilities, valid only for extended graphs (by default, True).
-    :param edges_value: a boolean indicating whether to display the transition probability of every edge (by default, True).
-    :param force_standard: a boolean indicating whether to use a standard graph even if Graphviz and Pydot are installed (by default, False).
-    :param dpi: the resolution of the plot expressed in dots per inch (by default, 100).
-    :return: None if Matplotlib is in interactive mode as the plot is immediately displayed, otherwise the handles of the plot.
+    :param nodes_color: a boolean indicating whether to display colored nodes based on communicating classes.
+    :param nodes_type: a boolean indicating whether to use a different shape for every node type.
+    :param edges_color: a boolean indicating whether to display edges using a gradient based on transition probabilities, valid only for extended graphs.
+    :param edges_value: a boolean indicating whether to display the transition probability of every edge.
+    :param force_standard: a boolean indicating whether to use a standard graph even if extended graphs are available.
+    :param dpi: the resolution of the plot expressed in dots per inch.
     :raises ValidationError: if any input argument is not compliant.
     """
 
@@ -180,7 +208,7 @@ def plot_graph(mc: tmc, nodes_color: bool = True, nodes_type: bool = True, edges
         colors_limit = len(_colors) - 1
         offset = 0
 
-        clist = list()
+        clist = []
 
         while count > 0:
 
@@ -215,16 +243,14 @@ def plot_graph(mc: tmc, nodes_color: bool = True, nodes_type: bool = True, edges
 
         # noinspection PyBroadException
         try:
-            call(['dot', '-V'], stdout=PIPE, stderr=PIPE)
+            call(['dot', '-V'], stdout=pipe, stderr=pipe)
         except Exception:  # pragma: no cover
             extended_graph = False
-            pass
 
         try:
-            import pydot as pyd  # noqa
+            import pydot  # noqa
         except ImportError:  # pragma: no cover
             extended_graph = False
-            pass
 
     g = mc.to_graph()
 
@@ -236,10 +262,10 @@ def plot_graph(mc: tmc, nodes_color: bool = True, nodes_type: bool = True, edges
             c = node_colors(len(mc.communicating_classes))
             for node in g_pydot.get_nodes():
                 state = node.get_name()
-                for x, cc in enumerate(mc.communicating_classes):
+                for index, cc in enumerate(mc.communicating_classes):
                     if state in cc:
                         node.set_style('filled')
-                        node.set_fillcolor(c[x])
+                        node.set_fillcolor(c[index])
                         break
 
         if nodes_type:
@@ -270,17 +296,17 @@ def plot_graph(mc: tmc, nodes_color: bool = True, nodes_type: bool = True, edges
         img_x = img.shape[0] / dpi
         img_y = img.shape[1] / dpi
 
-        figure = pp.figure(figsize=(img_y + 1.1, img_x + 1.1), dpi=dpi)
+        figure = mplp.figure(figsize=(img_y + 1.1, img_x + 1.1), dpi=dpi)
         figure.figimage(img)
         ax = figure.gca()
         ax.axis('off')
 
     else:
 
-        mpi = pp.isinteractive()
-        pp.interactive(False)
+        mpi = mplp.isinteractive()
+        mplp.interactive(False)
 
-        figure, ax = pp.subplots(dpi=dpi)
+        figure, ax = mplp.subplots(dpi=dpi)
 
         positions = nx.spring_layout(g)
         node_colors_all = node_colors(len(mc.communicating_classes))
@@ -290,9 +316,9 @@ def plot_graph(mc: tmc, nodes_color: bool = True, nodes_type: bool = True, edges
             node_color = None
 
             if nodes_color:
-                for x, cc in enumerate(mc.communicating_classes):
+                for index, cc in enumerate(mc.communicating_classes):
                     if node in cc:
-                        node_color = node_colors_all[x]
+                        node_color = node_colors_all[index]
                         break
 
             if nodes_type:
@@ -318,7 +344,7 @@ def plot_graph(mc: tmc, nodes_color: bool = True, nodes_type: bool = True, edges
 
         if edges_value:
 
-            edges_values = dict()
+            edges_values = {}
 
             for edge in g.edges:
                 probability = mc.transition_probability(edge[1], edge[0])
@@ -326,10 +352,10 @@ def plot_graph(mc: tmc, nodes_color: bool = True, nodes_type: bool = True, edges
 
             nx.draw_networkx_edge_labels(g, positions, ax=ax, edge_labels=edges_values, label_pos=0.7)
 
-        pp.interactive(mpi)
+        mplp.interactive(mpi)
 
-    if pp.isinteractive():  # pragma: no cover
-        pp.show(block=False)
+    if mplp.isinteractive():  # pragma: no cover
+        mplp.show(block=False)
         return None
 
     return figure, ax
@@ -340,12 +366,17 @@ def plot_redistributions(mc: tmc, distributions: tdists_flex, initial_status: os
     """
     The function plots a redistribution of states on the given Markov chain.
 
+    | **Notes:**
+
+    * If `Matplotlib <https://matplotlib.org/>`_ is in `interactive mode <https://matplotlib.org/stable/users/interactive.html>`_, the plot is immediately displayed and the function does not return the plot handles.
+
     :param mc: the target Markov chain.
     :param distributions: a sequence of redistributions or the number of redistributions to perform.
-    :param initial_status: the initial state or the initial distribution of the states (if omitted, the states are assumed to be uniformly distributed).
-    :param plot_type: the type of plot to display (either heatmap or projection; projection by default).
-    :param dpi: the resolution of the plot expressed in dots per inch (by default, 100).
-    :return: None if Matplotlib is in interactive mode as the plot is immediately displayed, otherwise the handles of the plot.
+    :param initial_status: the initial state or the initial distribution of the states (*if omitted, the states are assumed to be uniformly distributed*).
+    :param plot_type:
+     - **heatmap** for displaying an heatmap plot;
+     - **projection** for displaying a projection plot.
+    :param dpi: the resolution of the plot expressed in dots per inch.
     :raises ValueError: if the "distributions" parameter represents a sequence of redistributions and the "initial_status" parameter does not match its first element.
     :raises ValidationError: if any input argument is not compliant.
     """
@@ -370,7 +401,7 @@ def plot_redistributions(mc: tmc, distributions: tdists_flex, initial_status: os
     distributions_len = 1 if isinstance(distributions, np.ndarray) else len(distributions)
     distributions = np.array([distributions]) if isinstance(distributions, np.ndarray) else np.array(distributions)
 
-    figure, ax = pp.subplots(dpi=dpi)
+    figure, ax = mplp.subplots(dpi=dpi)
 
     if plot_type == 'heatmap':
 
@@ -425,10 +456,10 @@ def plot_redistributions(mc: tmc, distributions: tdists_flex, initial_status: os
         ax.legend(bbox_to_anchor=(0.5, -0.15), loc='upper center', ncol=legend_size)
         ax.set_title('Redistplot (Projection)', fontsize=15.0, fontweight='bold')
 
-        pp.subplots_adjust(bottom=0.2)
+        mplp.subplots_adjust(bottom=0.2)
 
-    if pp.isinteractive():  # pragma: no cover
-        pp.show(block=False)
+    if mplp.isinteractive():  # pragma: no cover
+        mplp.show(block=False)
         return None
 
     return figure, ax
@@ -439,12 +470,18 @@ def plot_walk(mc: tmc, walk: twalk_flex, initial_state: ostate = None, plot_type
     """
     The function plots a random walk on the given Markov chain.
 
+    | **Notes:**
+
+    * If `Matplotlib <https://matplotlib.org/>`_ is in `interactive mode <https://matplotlib.org/stable/users/interactive.html>`_, the plot is immediately displayed and the function does not return the plot handles.
+
     :param mc: the target Markov chain.
     :param walk: a sequence of states or the number of simulations to perform.
-    :param initial_state: the initial state of the walk (if omitted, it is chosen uniformly at random).
-    :param plot_type: the type of plot to display (one of histogram, sequence and transitions; histogram by default).
-    :param dpi: the resolution of the plot expressed in dots per inch (by default, 100).
-    :return: None if Matplotlib is in interactive mode as the plot is immediately displayed, otherwise the handles of the plot.
+    :param initial_state: the initial state of the walk (*if omitted, it is chosen uniformly at random*).
+    :param plot_type:
+     - **histogram** for displaying an histogram plot;
+     - **sequence** for displaying a sequence plot;
+     - **transitions** for displaying a transitions plot.
+    :param dpi: the resolution of the plot expressed in dots per inch.
     :raises ValueError: if the "walk" parameter represents a sequence of states and the "initial_state" parameter does not match its first element.
     :raises ValidationError: if any input argument is not compliant.
     """
@@ -475,14 +512,14 @@ def plot_walk(mc: tmc, walk: twalk_flex, initial_state: ostate = None, plot_type
 
     walk_len = len(walk)
 
-    figure, ax = pp.subplots(dpi=dpi)
+    figure, ax = mplp.subplots(dpi=dpi)
 
     if plot_type == 'histogram':
 
         walk_histogram = np.zeros((mc.size, walk_len), dtype=float)
 
-        for i, s in enumerate(walk):
-            walk_histogram[s, i] = 1.0
+        for index, state in enumerate(walk):
+            walk_histogram[state, index] = 1.0
 
         walk_histogram = np.sum(walk_histogram, axis=1) / np.sum(walk_histogram)
 
@@ -502,8 +539,8 @@ def plot_walk(mc: tmc, walk: twalk_flex, initial_state: ostate = None, plot_type
 
         walk_sequence = np.zeros((mc.size, walk_len), dtype=float)
 
-        for i, s in enumerate(walk):
-            walk_sequence[s, i] = 1.0
+        for index, state in enumerate(walk):
+            walk_sequence[state, index] = 1.0
 
         color_map = mplc.LinearSegmentedColormap.from_list('ColorMap', [_color_white, _colors[0]], 2)
         ax.imshow(walk_sequence, aspect='auto', cmap=color_map, interpolation='none', vmin=0.0, vmax=1.0)
@@ -550,8 +587,8 @@ def plot_walk(mc: tmc, walk: twalk_flex, initial_state: ostate = None, plot_type
 
         ax.set_title('Walkplot (Transitions)', fontsize=15.0, fontweight='bold')
 
-    if pp.isinteractive():  # pragma: no cover
-        pp.show(block=False)
+    if mplp.isinteractive():  # pragma: no cover
+        mplp.show(block=False)
         return None
 
     return figure, ax
