@@ -5,26 +5,13 @@
 # IMPORTS #
 ###########
 
-# Full
-
-import numpy.random as npr
-import numpy.testing as npt
-
-# Partial
+# Standard
 
 from os import (
     close,
     remove
 )
 
-from pydtmc import (
-    MarkovChain
-)
-
-from pytest import (
-    mark
-)
-
 from random import (
     randint
 )
@@ -33,6 +20,21 @@ from tempfile import (
     mkstemp
 )
 
+# Libraries
+
+import numpy.random as npr
+import numpy.testing as npt
+
+from pytest import (
+    mark
+)
+
+# Internal
+
+from pydtmc import (
+    MarkovChain
+)
+
 
 #########
 # TESTS #
@@ -97,8 +99,6 @@ def test_file(seed, maximum_size, runs, file_extension):
             mc_from = None
             exception = True
 
-            pass
-
         remove(file_path)
 
         assert exception is False
